import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Views/PaginationView.dart';
import 'package:quiver/iterables.dart';

class CustomListRowView extends StatelessWidget {
  final List<Widget> children;
  final double itemCount;
  final Future<void> Function() callback;
  final String text;
  final Function navigate;

  CustomListRowView({
    this.children,
    this.itemCount,
    this.callback,
    this.text,
    this.navigate
  });

  Widget _buildChild(Widget child) {
    return children.isEmpty && text != "" ? Padding(
      padding: const EdgeInsets.only(top: 16.0),
      child: DefaultTextStyle(
        style: TextStyle(fontSize: 18, color: Colors.black),
        child: Column(
          children: GetPaddedChildrenUtil().getPaddedChildren([
            Text("No food items found"),
            Text("Tap to request"),
            GestureDetector(onTap: () {
              navigate();
            }, child: Text(text, style: TextStyle(fontSize: 18,color: Colors.blue, decoration: TextDecoration.underline)))
          ]),
        ),
      ),
    ) : child;
  }

  @override
  Widget build(BuildContext context) {
    return PaginationView(child: (scrollController, circularProgressIndicator) {
      return LayoutBuilder(builder: (context, constraints) {
        if (constraints.maxWidth < 600) {
          return Scrollbar(
            child: _buildChild(ListView(
              controller: scrollController,
              children: [...children, circularProgressIndicator],
            ))
          );
        } else {
          return Scrollbar(
            child: _buildChild(ListView(
              padding: EdgeInsets.zero,
              controller: scrollController,
              children: [...[for (final subChildren in partition(children, itemCount.toInt())) Row(crossAxisAlignment: CrossAxisAlignment.start, mainAxisAlignment: MainAxisAlignment.center, children: [for (final child in subChildren) child])], circularProgressIndicator],
            )),
          );
        }
      });
    }, callback: callback);
  }
}
