import 'package:flutter/material.dart';
import 'package:flutter_helper/src/Views/ButtonView.dart';
import 'package:intl/intl.dart';

class DateView extends StatefulWidget {
  final Function onSelected;
  final DateTime dateTime;
  final String text;

  DateView({this.onSelected, this.dateTime, this.text});

  @override
  _DateViewState createState() => _DateViewState();
}

class _DateViewState extends State<DateView> {
  Future<DateTime> _showDatePicker(BuildContext context) async {
    final bool isNull = widget.dateTime == null || widget.dateTime == DateTime(3000);

    return showDatePicker(
        context: context,
        initialDate: isNull ? DateTime.now() : widget.dateTime,
        firstDate: DateTime(2000),
        lastDate: DateTime(3000)
    );
  }

  @override
  Widget build(BuildContext context) {
    final bool isNull = widget.dateTime == null || widget.dateTime == DateTime(3000);

    return ButtonView(
        iconData: Icons.calendar_today,
        text: isNull ? widget.text ?? "Select date" : "${DateFormat.yMMMMd(Localizations.localeOf(context).toLanguageTag()).format(widget.dateTime)}",
        onPressed: () async {
          final DateTime dateTime = await _showDatePicker(context);

          if (dateTime != null) {
            widget.onSelected(dateTime);
          }
        });
  }
}
