import 'package:flutter/material.dart';
import 'package:flutter_helper/src/Views/IconBackgroundView.dart';
import 'package:flutter_helper/src/Views/ImageView.dart';
import 'package:image_picker/image_picker.dart';

class ImagePickerView extends StatelessWidget {
  final List<String> images;
  final Function addImage;
  final Function(String) removeImage;
  final bool isLoading;
  final int i;

  ImagePickerView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading,
    this.i
  });

  Future<ImageSource> _showDialog(BuildContext context) async {
    final ImageSource imageSource = await showDialog(context: context, builder: (context) {
      return AlertDialog(
        title: Text("Where do you want to get your pictures from?"),
        actions: [
          FlatButton(onPressed: () {
            Navigator.pop(context, ImageSource.gallery);
          }, child: Text("Gallery")),
          FlatButton(onPressed: () {
            Navigator.pop(context, ImageSource.camera);
          }, child: Text("Camera"))
        ],
      );
    });

    return imageSource;
  }

  Widget _buildPicture(int index, BuildContext context) {
    Widget icon;

    Key key;

    if (images.length >= index) {
      icon = isLoading ? Center(child: SizedBox(width: 50.0, height: 50.0, child: CircularProgressIndicator())) : Icon(Icons.add_a_photo);

      key = Key("camera_plus");
    } else {
      icon = Icon(Icons.photo_camera);

      key = Key("camera");
    }

    Widget widget;

    if (images.length - 1 >= index) {
      widget = Center(
        child: GestureDetector(
            child: ClipOval(child: SizedBox(width: 100.0, height: 100.0, child: ImageView(image: images[index]))),
            onTap: () {
              removeImage(images[index]);
            }
        ),
      );
    } else {
      widget = Center(
        child: IconBackgroundView(
          key: key,
          icon: icon,
          onPressed: key == Key("camera_plus") ? () async {
            final ImageSource imageSource = await _showDialog(context);

            if (imageSource != null) {
              addImage(imageSource);
            }
          } : null,
          radius: 100.0,
        ),
      );
    }

    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: widget,
    );
  }

  @override
  Widget build(BuildContext context) {
    return _buildPicture(i, context);
  }
}
