import 'package:flutter/material.dart';

class TextFieldView extends StatelessWidget {
  final String label;
  final TextEditingController controller;
  final Widget prefixIcon;
  final Widget suffixIcon;
  final TextCapitalization textCapitalization;
  final bool obscureText;
  final String hintText;
  final TextInputType keyboardType;
  final bool autofocus;
  final bool isMandatory;
  final Function onSubmitted;
  final TextInputAction textInputAction;
  final int maxLines;
  final Function validator;
  final double fontSize;
  final bool readOnly;
  final Function onTap;
  final FocusNode focusNode;
  
  TextFieldView({
    this.label,
    this.controller,
    this.prefixIcon,
    this.suffixIcon,
    this.textCapitalization,
    this.obscureText,
    this.hintText,
    this.keyboardType,
    this.autofocus,
    this.isMandatory,
    this.onSubmitted,
    this.textInputAction,
    this.maxLines,
    this.validator,
    this.fontSize,
    this.readOnly,
    this.onTap,
    this.focusNode
  });
  
  @override
  Widget build(BuildContext context) {
    return TextFormField(
      focusNode: focusNode,
      onTap: onTap,
      readOnly: readOnly ?? false,
      textInputAction: textInputAction,
      onFieldSubmitted: onSubmitted,
      keyboardType: keyboardType,
      validator: isMandatory != null && isMandatory ? (String value) {
        if (value.isEmpty) {
          return "Please enter some text";
        } else {
          return null;
        }
      } : validator != null ? validator : null,
      controller: controller,
      style: TextStyle(fontSize: fontSize ?? 16.0),
      autofocus: autofocus ?? false,
      decoration: InputDecoration(
        prefixIcon: prefixIcon,
        suffixIcon: suffixIcon,
        hintText: hintText,
        labelText: label,
      ),
      textCapitalization: textCapitalization ?? TextCapitalization.none,
      maxLines: maxLines ?? 1,
      obscureText: obscureText ?? false,
    );
  }
}
